TPStreamsDownloadManager class

Constructors

TPStreamsDownloadManager()

Properties

downloadsStream → Stream<List<DownloadAsset>>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelDownload(DownloadAsset asset) → Future<void>
deleteAllDownloads() → Future<void>
deleteDownload(DownloadAsset asset) → Future<void>
dispose() → dynamic
getAllDownloads() → Future<List<DownloadAsset>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseDownload(DownloadAsset asset) → Future<void>
resumeDownload(DownloadAsset asset) → Future<void>
startDownload(String assetId, [String? accessToken, Map<String, String>? metadata, String? resolution]) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited