DownloadAsset class

Constructors

DownloadAsset({required String assetId, String? title, required DownloadState state, required double progress, required int totalSize, required int downloadedSize, String? thumbnailUrl, Map<String, String>? metadata})

Properties

assetId ↔ String
getter/setter pair
downloadedSize ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, String>?
getter/setter pair
progress ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ DownloadState
getter/setter pair
thumbnailUrl ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair
totalSize ↔ int
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → DownloadAsset