ImageWatermarkConfig class

Constructors

ImageWatermarkConfig({required String imageUrl, int width = 48, int height = 48, int x = 92, int y = 88, double opacity = 1.0})

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
imageUrl ↔ String
getter/setter pair
opacity ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int
getter/setter pair
x ↔ int
getter/setter pair
y ↔ int
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → ImageWatermarkConfig