WatermarkConfig class

Constructors

WatermarkConfig({required String text, int x = 0, int y = 0, int color = 0xFFFFFFFF, double textSize = 14.0, double opacity = 0.3, WatermarkAnimation? animation})

Properties

animation WatermarkAnimation?
getter/setter pair
color int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
opacity double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
getter/setter pair
textSize double
getter/setter pair
x int
getter/setter pair
y int
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) WatermarkConfig