TPStreamsPlayerPreferences class

Constructors

TPStreamsPlayerPreferences({required bool enableFullscreen, required bool enablePlaybackSpeed, required bool enableCaptions, required bool showResolutionOptions, required bool enableSeekButtons, int? seekBarColor})

Properties

enableCaptions ↔ bool
getter/setter pair
enableFullscreen ↔ bool
getter/setter pair
enablePlaybackSpeed ↔ bool
getter/setter pair
enableSeekButtons ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seekBarColor ↔ int?
getter/setter pair
showResolutionOptions ↔ bool
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → TPStreamsPlayerPreferences