enableAutoFullscreenOnRotate method

Future<void> enableAutoFullscreenOnRotate()

Enables or disables automatic fullscreen mode when the device is rotated to landscape. Android: Player will automatically enter fullscreen on landscape rotation and exit on portrait rotation. iOS: Currently a no-op.

Implementation

Future<void> enableAutoFullscreenOnRotate() =>
    _nativeApi.enableAutoFullscreenOnRotate();