TPStreamsPlayerValue class

Represents the state of a streams player.

Constructors

TPStreamsPlayerValue({bool isLoading = false, Duration duration = Duration.zero, Duration position = Duration.zero, bool isPlaying = false, bool isBuffering = false, bool isEnded = false, bool isFullScreen = false, TPStreamsError? error})
const

Properties

duration → Duration
The total duration of the video. Defaults to Duration.zero if the video is not loaded.
final
error → TPStreamsError?
Any error that occurred during playback
final
hashCode → int
The hash code for this object.
no setterinherited
isBuffering → bool
Indicates whether the video is currently buffering.
final
isEnded → bool
Indicates whether the currently loaded video has played to the end.
final
isFullScreen → bool
Indicates whether the video is currently in fullscreen mode.
final
isLoading → bool
Indicates whether a video is currently being loaded into the player.
final
isPlaying → bool
Indicates whether the video is currently playing (true) or paused (false).
final
position → Duration
The current playback position in the video.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isLoading, Duration? duration, Duration? position, bool? isPlaying, bool? isBuffering, bool? isEnded, bool? isFullScreen, Object? error = _noErrorUpdate}) → TPStreamsPlayerValue
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited