TPStreamPlayer class

Inheritance

Constructors

TPStreamPlayer({Key? key, required String assetId, String? accessToken, double aspectRatio = 16 / 9, dynamic onPlayerCreated(TPStreamsPlayerController controller)?, bool? showDownloadOption = false, bool? startInFullscreen = false, int? offlineLicenseExpireDays = 15, Map<String, String>? metadata, bool autoPlay = true, int? resolution, String? userId, TPStreamsPlayerPreferences? preferences})
TPStreamPlayer.offline({Key? key, required String assetId, double aspectRatio = 16 / 9, dynamic onPlayerCreated(TPStreamsPlayerController controller)?, bool autoPlay = true, String? userId, Map<String, String>? metadata})

Properties

accessToken → String?
final
aspectRatio → double
final
assetId → String
final
autoPlay → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
metadata → Map<String, String>?
final
offlineLicenseExpireDays → int?
final
onPlayerCreated → dynamic Function(TPStreamsPlayerController controller)?
final
preferences → TPStreamsPlayerPreferences
final
resolution → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDownloadOption → bool?
final
startInFullscreen → bool?
final
userId → String?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<TPStreamPlayer>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited