ImageWatermarkConfig class

Inheritance

Constructors

ImageWatermarkConfig({required String imageUrl, int width = 48, int height = 48, int x = 92, int y = 88, double opacity = 1.0})

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → int
final
imageUrl → String
final
opacity → double
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
final
x → int
finalinherited
y → int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPigeon() → BaseWatermarkConfig
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited