setMaxResolution method
Sets the maximum resolution for video playback.
The resolution parameter defines the maximum video height in pixels (for example, 720 for 720p).
Android: Limits playback to video tracks whose resolution is less than or equal to the specified value. Higher-resolution tracks will not be selected.
iOS: Currently a no-op (the setting is ignored).
Implementation
Future<void> setMaxResolution(int resolution) => _nativeApi.setMaxResolution(resolution);