TextWatermarkConfig class
- Inheritance
-
- Object
- BaseWatermarkConfig
- TextWatermarkConfig
Constructors
- TextWatermarkConfig({required String text, int x = 0, int y = 0, int color = 0xFFFFFFFF, double textSize = 14.0, double opacity = 0.3, FlutterWatermarkAnimation? animation})
Properties
- animation → FlutterWatermarkAnimation?
-
final
- color → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- opacity → double
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
final
- textSize → double
-
final
- x → int
-
finalinherited
- y → int
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPigeon(
) → FlutterBaseWatermarkConfig -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited